==> bootstrap-submenu-2.0.3.tgz: package/README.md <==
# [Bootstrap-submenu](https://vsn4ik.github.io/bootstrap-submenu/)

[![Bower version](https://img.shields.io/bower/v/bootstrap-submenu.svg)](https://github.com/vsn4ik/bootstrap-submenu)
[![npm version](https://img.shields.io/npm/v/bootstrap-submenu.svg)](https://www.npmjs.com/package/bootstrap-submenu)
[![License](https://img.shields.io/npm/l/bootstrap-submenu.svg)][license]
[![Build Status](https://travis-ci.org/vsn4ik/bootstrap-submenu.svg)](https://travis-ci.org/vsn4ik/bootstrap-submenu)
[![devDependency Status](https://david-dm.org/vsn4ik/bootstrap-submenu/dev-status.svg)](https://david-dm.org/vsn4ik/bootstrap-submenu#info=devDependencies)


## Quick start

Several quick start options are available:

* [Download the latest release](https://github.com/vsn4ik/bootstrap-submenu/releases/download/v2.0.3/bootstrap-submenu-2.0.3-dist.zip "Download Bootstrap-submenu").
* Clone the repo: `git clone https://github.com/vsn4ik/bootstrap-submenu.git`.
* Install with [Bower](http://bower.io): `bower install bootstrap-submenu`.
* Install with [npm](https://www.npmjs.com): `npm install bootstrap-submenu`.
* Install with [SPM](http://spmjs.io): `spm install bootstrap-submenu`.
* Install with [Composer](https://getcomposer.org): `composer require vsn4ik/bootstrap-submenu "dev-master"`.

### What's included

```
bootstrap-submenu/
├── css/
│   ├── bootstrap-submenu.css
│   ├── bootstrap-submenu.css.map
│   ├── bootstrap-submenu.min.css
│   └── bootstrap-submenu.min.css.map
└── js/
    ├── bootstrap-submenu.js
    └── bootstrap-submenu.min.js
```


## Examples

For some working examples, visit our [examples](https://vsn4ik.github.io/bootstrap-submenu/#html-examples) section.


## Min Requirements

* Bootstrap 3.0.0
* jQuery 1.9.1


## Creators

**Vasily A.**

* <https://github.com/vsn4ik>


## Copyright and license

Copyright Vasily A., 2014&ndash;2015.

Licensed under [the MIT License][license].

[license]: https://github.com/vsn4ik/bootstrap-submenu/blob/master/LICENSE

==> bootstrap-submenu-2.0.4.tgz: package/README.md <==
# [Bootstrap-submenu](https://vsn4ik.github.io/bootstrap-submenu/)

[![Bower version](https://img.shields.io/bower/v/bootstrap-submenu.svg)](https://github.com/vsn4ik/bootstrap-submenu)
[![npm version](https://img.shields.io/npm/v/bootstrap-submenu.svg)](https://www.npmjs.com/package/bootstrap-submenu)
[![License](https://img.shields.io/npm/l/bootstrap-submenu.svg)][license]
[![Build Status](https://travis-ci.org/vsn4ik/bootstrap-submenu.svg)](https://travis-ci.org/vsn4ik/bootstrap-submenu)
[![devDependency Status](https://david-dm.org/vsn4ik/bootstrap-submenu/dev-status.svg)](https://david-dm.org/vsn4ik/bootstrap-submenu#info=devDependencies)


## Quick start

Several quick start options are available:

* [Download the latest release](https://github.com/vsn4ik/bootstrap-submenu/archive/v2.0.4.zip "Download Bootstrap-submenu").
* Clone the repo: `git clone https://github.com/vsn4ik/bootstrap-submenu.git`.
* Install with [Bower](http://bower.io): `bower install bootstrap-submenu`.
* Install with [npm](https://www.npmjs.com): `npm install bootstrap-submenu`.
* Install with [Composer](https://getcomposer.org): `composer require vsn4ik/bootstrap-submenu "dev-master"`.

### What's included

```
bootstrap-submenu/
├── css/
│   ├── bootstrap-submenu.css
│   ├── bootstrap-submenu.css.map
│   └── bootstrap-submenu.min.css
└── js/
    ├── bootstrap-submenu.js
    └── bootstrap-submenu.min.js
```


## Examples

For some working examples, visit our [examples](https://vsn4ik.github.io/bootstrap-submenu/#html-examples) section.


## Min Requirements

* Bootstrap 3.0.0
* jQuery 1.9.1


## Creators

**Vasily A.**

* <https://github.com/vsn4ik>


## Copyright and license

Copyright Vasily A., 2014&ndash;2016.

Licensed under [the MIT License][license].

[license]: https://github.com/vsn4ik/bootstrap-submenu/blob/master/LICENSE
